/*
 * DO NOT EDIT.  THIS FILE IS GENERATED FROM /builds/slave/cen-osx64-xr/build/dom/interfaces/html/nsIDOMHTMLUnknownElement.idl
 */

#ifndef __gen_nsIDOMHTMLUnknownElement_h__
#define __gen_nsIDOMHTMLUnknownElement_h__


#ifndef __gen_nsIDOMHTMLElement_h__
#include "nsIDOMHTMLElement.h"
#endif

/* For IDL files that don't want to include root IDL files. */
#ifndef NS_NO_VTABLE
#define NS_NO_VTABLE
#endif

/* starting interface:    nsIDOMHTMLUnknownElement */
#define NS_IDOMHTMLUNKNOWNELEMENT_IID_STR "13d29c53-a9a6-45b8-bb69-e5294bb6e09e"

#define NS_IDOMHTMLUNKNOWNELEMENT_IID \
  {0x13d29c53, 0xa9a6, 0x45b8, \
    { 0xbb, 0x69, 0xe5, 0x29, 0x4b, 0xb6, 0xe0, 0x9e }}

/**
 * The nsIDOMHTMLUnknownElement interface is the interface to an unknown HTML
 * element.
 *
 * @see <http://www.whatwg.org/html/#htmlunknownelement>
 */
class NS_NO_VTABLE NS_SCRIPTABLE nsIDOMHTMLUnknownElement : public nsIDOMHTMLElement {
 public: 

  NS_DECLARE_STATIC_IID_ACCESSOR(NS_IDOMHTMLUNKNOWNELEMENT_IID)

};

  NS_DEFINE_STATIC_IID_ACCESSOR(nsIDOMHTMLUnknownElement, NS_IDOMHTMLUNKNOWNELEMENT_IID)

/* Use this macro when declaring classes that implement this interface. */
#define NS_DECL_NSIDOMHTMLUNKNOWNELEMENT \
  /* no methods! */

/* Use this macro to declare functions that forward the behavior of this interface to another object. */
#define NS_FORWARD_NSIDOMHTMLUNKNOWNELEMENT(_to) \
  /* no methods! */

/* Use this macro to declare functions that forward the behavior of this interface to another object in a safe way. */
#define NS_FORWARD_SAFE_NSIDOMHTMLUNKNOWNELEMENT(_to) \
  /* no methods! */

#if 0
/* Use the code below as a template for the implementation class for this interface. */

/* Header file */
class nsDOMHTMLUnknownElement : public nsIDOMHTMLUnknownElement
{
public:
  NS_DECL_ISUPPORTS
  NS_DECL_NSIDOMHTMLUNKNOWNELEMENT

  nsDOMHTMLUnknownElement();

private:
  ~nsDOMHTMLUnknownElement();

protected:
  /* additional members */
};

/* Implementation file */
NS_IMPL_ISUPPORTS1(nsDOMHTMLUnknownElement, nsIDOMHTMLUnknownElement)

nsDOMHTMLUnknownElement::nsDOMHTMLUnknownElement()
{
  /* member initializers and constructor code */
}

nsDOMHTMLUnknownElement::~nsDOMHTMLUnknownElement()
{
  /* destructor code */
}

/* End of implementation class template. */
#endif


#endif /* __gen_nsIDOMHTMLUnknownElement_h__ */
